<TS language="hu_HU" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>A cím vagy a címke jobb gombbal szerkeszthető</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Új cím létrehozása</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Új</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>A jelenleg kiválasztott cím másolása a rendszer vágólapjára</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Másolás</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>A jelenleg kiválasztott cím eltávolítása a listából</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>A jelenlegi fülön található adat exportálása fájlba</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Export</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Válasszon címet a küldéshez</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Válasszon címet a fogadáshoz</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Kiválasztás</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Küldő címek</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Fogadó címek</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Ezek az Ön kifizetéseinek küldésekor használandó Litecoin-címek. Fizetés indítása előtt mindig ellenőrizze az összeget és a fogadó címet!</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Ezek az Ön fizetéseinek fogadásakor használandó Litecoin-címek. Célszerű minden tranzakcióhoz új fogadó címet használni.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Cím másolása</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Címke &amp;másolása</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkesztés</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Címlista exportálása</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Vesszővel elválasztott adatok (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Sikertelen export</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Hiba történt a címlista %1-re történő mentése során. Kérjük, próbálja újra!</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Jelszóhalmaz Párbeszédablak</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Adja meg jelmondatát</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Új jelmondat</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ismételje meg jelmondatát</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Jelszó megjelenítése</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Adja meg az új jelszóhalmazt a pénztárcájához. &lt;br/&gt;Kérem a jelszóhalmaz álljon&lt;b&gt;tíz vagy több véletlenszerű karakterből&lt;/b&gt;, vagy &lt;b&gt;nyolc vagy több szóból&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Tárca kódolása</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ehhez a művelethez szükség lesz a pénztárcájához tartozó jelszóhalmazra, hogy hozzáférjen a  pénztárcához.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Tárca feloldása</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ehhez a művelethez szükség lesz a pénztárcájához tartozó jelszóhalmazra, hogy feloldja a pénztárca titkosítását.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Tárca dekódolása</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Jelmondat megváltoztatása</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Adja meg a régi jelszóhalmazt és az új jelszóhalmazt a pénztárcájához.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Tárca titkosításának jóváhagyása</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Figyelem: Ha titkosítja a pénztárcáját, és elveszíti a jelszóhalmazt, akkor &lt;b&gt;NEM TUD TÖBBET HOZZÁFÉRNI A LITECOINJAIHOZ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Biztosan titkosítani kívánja a tárcáját?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Tárca titkosítva</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>FONTOS: A régebbi biztonsági mentéseket frissítse az új, titkosított pénztárca fájllal. Biztonsági okokból, a korábbi titkosítatlan pénztárca fájlok nem használhatóak az új titkosított pénztárcával.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Tárca titkosítása sikertelen</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>A pénztárca titkosítása programhiba miatt meghiúsult .  A pénztárca nem titkosított.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>A megadott jelszóhalmazok nem egyeznek.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Tárca feloldása sikertelen</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>A jelszóhalmaz, amelyet megadott a pénztárca titkosításának a feloldásához, helytelen.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Tárca dekódolása sikertelen</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>A tárca jelmondata sikeresen megváltozott.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Figyelmeztetés: A Caps Lock billentyű benyomva!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Kitiltva a megadott időpontig</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Üzenet &amp;aláírása</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Szinkronizálás a hálózattal...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>Á&amp;ttekintés</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>A pénztárca általános áttekintése</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Tranzakciók</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Tranzakció-történet böngészése</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Ki&amp;lépés</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Alkalmazás bezárása</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Kapcsolat %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>További információ %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Kapcsolat &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>További információ Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Beállítások...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>A %1 konfigurációs beállításainak módosítása</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Tárca titkosítása</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Tárca &amp;biztonsági másolása</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Jelszóhalmaz megváltoztatása</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>&amp;URI... Megnyitása</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Kattintson a hálózati tevékenység felfüggesztéséhez.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Hálózati tevékenység letiltva.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Kattintson a hálózati tevékenység ismételt engedélyezéséhez.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Fejlécek szinkronizálása (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>A blokkok újraindexelése folyik a merevlemezen...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Érmék küldése egy Litecoin címre</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Tárca biztonsági mentése más helyre</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>A tárca titkosításához használt jelszóhalmaz megváltoztatása</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Hibakereső ablak</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Hibakereső és diagnosztikai konzol megnyitása</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Üzenet &amp;ellenőrzése</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Küldé&amp;s</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Fogadás</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Mutat/Elrejt</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Fő ablak megjelenítése vagy elrejtése</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Tárcájához tartozó privát kulcsok titkosítása</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Írja alá az üzeneteit a Litecoin címével, hogy bizonyítsa Öntől származnak</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Ellenőrizze az üzeneteket, hogy a megadott Litecoin címekkel lettek-e aláírva</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Sú&amp;gó</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Ablak fülek eszköztára</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Kérjen fizetéseket (QR kódokat generál és litecoin: URLeket)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Mutassa a használt küldő címek és cimkék listáját</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Mutassa a használt fogadó címek és cimkék listáját</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Nyisson meg egy litecoin: URI-t vagy fizetési kérelmet</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Parancssor beállításai</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Litecoin network</source>
        <translation><numerusform>%n aktív kapcsolat a Litecoin-hálózaton</numerusform><numerusform>%n aktív kapcsolat a Litecoin-hálózaton</numerusform></translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>A blokkok indexelése folyik a merevlemezen...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>A blokkok feldolgozása a merevlemezen...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>A tranzakció-történetből %n blokk feldolgozva.</numerusform><numerusform>A tranzakció-történetből %n blokk feldolgozva.</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 mögött</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Az utolsó kapott blokk %1 ideje keletkezett.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Az ez utáni tranzakciók még nem fognak látszani.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Naprakész</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
        <translation>Mutassa a %1 súgó üzenetet a lehetséges Litecoin parancssori beállítások listájáért</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ablak</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 kliens</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Kapcsolatok kialakítása...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Felzárkózás...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Dátum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Összeg: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Típus: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Címke: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Cím: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Elküldött tranzakció</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Bejövő tranzakció</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>HD kulcs generálás &lt;b&gt;engedélyezve&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>HD kulcs generálás &lt;b&gt;tiltva&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Tárca &lt;b&gt;titkosítva&lt;/b&gt; és jelenleg &lt;b&gt;nyitva&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Tárca &lt;b&gt;titkosítva&lt;/b&gt; és jelenleg &lt;b&gt;zárolva&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>Fatális hiba történt. A Litecoin program nem tud tovább biztonságosan működni és be fog záródni.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Érme választó</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Mennyiség:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bájtok:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Öszeg:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Díj:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Porszem:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Eljárási díj után:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Változás:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>minden kiválasztása(kiválasztás megszüntetése)</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Fa mód</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Lista mód</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Címkével fogadott</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Címmel fogadott</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Jóváhagyások</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Jóváhagyva</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Cím másolása</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Címke másolása</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Összeg másolása</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Tranzakció ID másolása</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>El nem költött zárolása</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>El nem költött nyitása</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Mennyiség másolása</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Díj másolása</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Eljárási díj utáni másolás</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Bájtok másolása</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Por másolása</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Változás másolása</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 zárolva)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>igen</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nem</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Ez a címke pirosra változik, ha valamelyik fogadó fél kisebb összeget kap, mint a jelenlegi porszem határérték.</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>Változó +/- %1 satoshi(k) megadott értékenként.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>változtatás %1 -ről (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(módosítás)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Cím szerkesztése</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Címke</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Ezzel a cím bejegyzéssel társított címke</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Ezzel a cím bejegyzéssel társított cím. Ezt csak a küldő címek esetén lehet megváltoztatni.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Cím</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Új küldési cím</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Fogadási cím szerkesztése</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Küldési cím szerkesztése</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Litecoin address.</source>
        <translation>A megadott cím"%1" nem egy érvényes Litecoin cím.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>A tárca feloldása nem lehetséges</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Új kulcs létrehozása sikertelen</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Új mappa lesz létrehozva.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>név</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>A könyvtár már létezik. %1 hozzáadása, ha új könyvtárat kíván létrehozni.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Az elérési út létezik, de nem egy mappa.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Itt nem hozható létre mappa.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>verzió</translation>
    </message>
    <message>
        <source>(%1-bit)</source>
        <translation>(%1-bit)</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Kapcsolat %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Parancssor beállításai</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Üdvözöljük</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Üdvözöljük itt: %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Mivel ez a program első indulása, megváltoztathatja %1 hova mentse az adatokat.</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation>Ha az OK-ra kattint, %1 megkezdi a teljes %4 blokk lánc letöltését és feldolgozását (%2GB) a legkorábbi tranzakciókkal kezdve %3 -ben, amikor a %4 bevezetésre került.</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation>Az első szinkronizáció nagyon erőforrás-igényes és felszínre hozhat a számítógépében eddig rejtve maradt hardver problémákat. Minden %1 indításnál a program onnan folytatja a letöltést, ahol legutóbb abbahagyta.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation>Ha a tárolt blokk lánc méretének korlátozását (megnyesését) választotta, akkor is le kell tölteni és feldolgozni az eddig keletkezett összes adatot, de utána ezek törlésre kerülnek, hogy ne foglaljunk sok helyet a merevlemezen.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Alapértelmezett adatmappa használata</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Egyéni adatmappa használata:</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Legalább  %1 GB adatot fogunk ebben a könyvtárban tárolni és idővel ez egyre több lesz.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation>Hozzávetőlegesen %1 GB adatot fogunk ebben a könyvtárban tárolni.</translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Litecoin block chain.</source>
        <translation>%1 le fog töltődni és a Litecoin blokk lánc egy másolatát fogja tárolni.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Ebben a könyvtárban lesz a pénztárca is.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>Hiba: A megadott könyvtárat "%1" nem sikerült létrehozni.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n GB szabad hely áll rendelkezésre</numerusform><numerusform>%n GB szabad hely áll rendelkezésre</numerusform></translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the litecoin network, as detailed below.</source>
        <translation>A legutóbbi tranzakciók még lehet, hogy nem látszanak, ezért előfordulhat, hogy a pénztárca egyenlege nem a valós állapotot mutatja. Ha a pénztárca befejezte a szinkronizációt a litecoin hálózattal, utána már az aktuális egyenleget fogja mutatni, amint alant részletesen látszik.</translation>
    </message>
    <message>
        <source>Attempting to spend litecoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation>A hálózat nem fogadja el azoknak a litecoinoknak az elköltését, amelyek érintettek a még nem látszódó tranzakciókban.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Hátralévő blokkok száma</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Ismeretlen...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Utolsó blokk ideje</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Folyamat</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation>A folyamat előrehaladása óránként</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>számolás...</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation>Hozzávetőlegesen a hátralévő idő a szinkronizáció befejezéséig</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Elrejtés</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>URI megnyitása</translation>
    </message>
    <message>
        <source>Open payment request from URI or file</source>
        <translation>Fizetési kérelem megnyitása URI-ból vagy fájlból</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    <message>
        <source>Select payment request file</source>
        <translation>A fizetési kérelem fájl kiválasztása</translation>
    </message>
    <message>
        <source>Select payment request file to open</source>
        <translation>Válassza ki a megnyitni kívánt fizetési kérelem fájlt</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciók</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Fő</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>%1 automatikus indítása a rendszerbe való belépés után.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>&amp;Induljon el a %1 a rendszerbe való belépéskor</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Az &amp;adatbázis cache mérete</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>A szkript &amp;igazolási szálak száma</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>Proxy IP címe (pl.: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Shows if the supplied default SOCKS5 proxy is used to reach peers via this network type.</source>
        <translation>Megmutatja, hogy az alapértelmezett SOCKS5 proxy van-e használatban, hogy elérje a párokat ennél a hálózati típusnál.</translation>
    </message>
    <message>
        <source>Hide the icon from the system tray.</source>
        <translation>Rejtse el az ikont a rendszer tálcáról.</translation>
    </message>
    <message>
        <source>&amp;Hide tray icon</source>
        <translation>&amp;Tálcaikon elrejtése</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation>Kilépés helyett a program elrejtése az ablak bezárása után. Ha engedélyezte ezt a beállítást, akkor csak úgy tud kilépni a programból, ha a menüből a Kilépés opciót választja.</translation>
    </message>
    <message>
        <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation>Harmadik féltől származó URL-ek (pl. egy blokk felfedező) amelyek a tranzakciós fülön jelennek meg mint a környezetérzékeny menü tételei. %s az URL-ben helyettesítve a tranzakciós hash-el. Több URL esetén, függőleges vonal választja el őket.</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation>A %1 konfigurációs fájl megnyitása a munkakönyvtárból.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Konfigurációs Fájl Megnyitása</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Minden kliens beállítás visszaállítása alaphelyzetbe.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Visszaállítja a Beállításokat</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Hálózat</translation>
    </message>
    <message>
        <source>(0 = auto, &lt;0 = leave that many cores free)</source>
        <translation>(0 = automatikus, &lt;0 = ennyi processzormagot hagyjon szabadon)</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>T&amp;árca</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>Pénzküldés beállításainak engedélyezése</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation>Ha letiltja a jóváhagyatlan visszajáró elköltését, akkor egy tranzakcióból származó visszajárót nem lehet felhasználni, amíg legalább egy jóváhagyás nem történik. Ez befolyásolja az egyenlegének a kiszámítását is.</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;Költése a a jóváhagyatlan visszajárónak</translation>
    </message>
    <message>
        <source>Automatically open the Litecoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Automatikusan nyissa meg a Litecoin kliens által használt portot a routeren. Ez csak akkor működik, ha a router támogatja a UPnP-t, és engedélyezett ez a beállítás.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Port feltérképezése &amp;UPnP használatával</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation>Kívülről érkező kapcsolatok fogadása.</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation>&amp;Bejövő kapcsolatok engedélyezése</translation>
    </message>
    <message>
        <source>Connect to the Litecoin network through a SOCKS5 proxy.</source>
        <translation>Csatlakozás a Litecoin hálózathoz SOCKS5 proxy használatával.</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation>&amp;Kapcsolódás SOCKS5 proxyn keresztül (alapértelmezett proxy):</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Proxy &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Port:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxy portja (pl.: 9050)</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation>Párok elérésére használjuk ezen keresztül:</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>Connect to the Litecoin network through a separate SOCKS5 proxy for Tor hidden services.</source>
        <translation>Csatlakozás a Litecoin hálózathoz külön SOCKS5 proxy használatával a Tor rejtett szolgáltatásainak eléréséhez.</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ablak</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Csak az ablak elrejtése után mutassa a tálca ikont.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Elrejtés a tálcára ikon formában, a tálcán látható futó program helyett</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>&amp;Elrejtés bezáráskor</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Mutatás</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Felhasználói felület &amp;nyelve:</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation>A felhasználói felület nyelvét tudja itt beállítani. Ez a beállítás csak a %1 újraindítása után lép életbe.</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Mértékegység amelyben mutassa az összegeket:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Válassza ki az alapértelmezett részmértékegységet, amely megjelenik a felhasználói felületen és pénzküldéskor.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>Mutassa a pénzküldés beállításait vagy ne.</translation>
    </message>
    <message>
        <source>&amp;Third party transaction URLs</source>
        <translation>&amp;Harmadik féltől származó tranzakciós URL-ek</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Mégse</translation>
    </message>
    <message>
        <source>default</source>
        <translation>alapméretezett</translation>
    </message>
    <message>
        <source>none</source>
        <translation>semmi</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Opciók visszaállításának megerősítése</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Újra kell indítani a programot a beállítások alkalmazásához.</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <translation>A kliens le fog állni. Szeretné folytatni?</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Beállítási lehetőségek</translation>
    </message>
    <message>
        <source>The configuration file is used to specify advanced user options which override GUI settings. Additionally, any command-line options will override this configuration file.</source>
        <translation>A konfigurációs fájlt a haladó felhasználók olyan beállításokra használhatják, amelyek felülírják a grafikus felület beállításait. Azonban bármely parancssori beállítás felülírja a konfigurációs fájl beállításait.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation>Nem sikerült megnyitni a konfigurációs fájlt.</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Ehhez a változtatáshoz újra kellene indítani a klienst.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>A megadott proxy cím érvénytelen.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Litecoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Lehet, hogy a megjelenített információ elavult. A tárcája automatikusan szinkronizál a hálózattal kapcsolódás után, de a folyamat még nem ért véget.</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation>Megfigyelés:</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Elérhető:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Felhasználható egyenlege</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Függőben:</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation>A tranzakciók száma, amelyeket még hitelesíteni kell, és amelyek még nem tartoznak az elkölthető egyenlegbe.</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Éretlen:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Bányászott egyenleg, mely jelenleg még éretlen</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Egyenlegek</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Összesen:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Jelenlegi teljes egyenlege</translation>
    </message>
    <message>
        <source>Your current balance in watch-only addresses</source>
        <translation>A csak megfigyelt címeinek az egyenlege</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>Elkölthető:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Legutóbbi tranzakciók</translation>
    </message>
    <message>
        <source>Unconfirmed transactions to watch-only addresses</source>
        <translation>A csak megfigyelt címek hitelesítetlen tranzakciói</translation>
    </message>
    <message>
        <source>Mined balance in watch-only addresses that has not yet matured</source>
        <translation>A csak megfigyelt címek bányászott, még éretlen egyenlege</translation>
    </message>
    <message>
        <source>Current total balance in watch-only addresses</source>
        <translation>A csak megfigyelt címek jelenlegi teljes egyenlege</translation>
    </message>
</context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Hiba történt a fizetési kérelem során</translation>
    </message>
    <message>
        <source>Cannot start litecoin: click-to-pay handler</source>
        <translation>A litecoin nem tud elindulni: click-to-pay kezelő</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI kezelése</translation>
    </message>
    <message>
        <source>Invalid payment address %1</source>
        <translation>Érvénytelen fizetési cím %1</translation>
    </message>
    <message>
        <source>URI cannot be parsed! This can be caused by an invalid Litecoin address or malformed URI parameters.</source>
        <translation>Az URI nem dolgozható fel! Ennek oka lehet egy érvénytelen Litecoin-cím, vagy hibás URI-paraméterek.</translation>
    </message>
    <message>
        <source>Payment request file handling</source>
        <translation>Fizetésikérelem-fájl kezelése</translation>
    </message>
    <message>
        <source>Payment request file cannot be read! This can be caused by an invalid payment request file.</source>
        <translation>A fizetésikérelem-fájl nem olvasható! Lehet, hogy hibás a fájl.</translation>
    </message>
    <message>
        <source>Payment request rejected</source>
        <translation>Fizetési kérelem elutasítva</translation>
    </message>
    <message>
        <source>Payment request network doesn't match client network.</source>
        <translation>A fizetési kérelem hálózat nem egyezik a kliens hálózatával.</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Fizetési kérelem lejárt</translation>
    </message>
    <message>
        <source>Payment request is not initialized.</source>
        <translation>Fizetési kérelem nincs inicializálva.</translation>
    </message>
    <message>
        <source>Invalid payment request.</source>
        <translation>Érvénytelen fizetési kérelem</translation>
    </message>
    <message>
        <source>Requested payment amount of %1 is too small (considered dust).</source>
        <translation>A %1 fizetésre kért összege túl kevés (porszemnek minősül).</translation>
    </message>
    <message>
        <source>Refund from %1</source>
        <translation>Visszatérítés innen: %1</translation>
    </message>
    <message>
        <source>Payment request %1 is too large (%2 bytes, allowed %3 bytes).</source>
        <translation>A %1 fizetési kérelem túl nagy (%2 bájt, megengedett: %3 bájt).</translation>
    </message>
    <message>
        <source>Error communicating with %1: %2</source>
        <translation>Hiba a kommunikáció során %1 -el: %2</translation>
    </message>
    <message>
        <source>Payment request cannot be parsed!</source>
        <translation>A fizetési kérelem nem dolgozható fel!</translation>
    </message>
    <message>
        <source>Bad response from server %1</source>
        <translation>Rossz válasz a szervertől %1</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Hálózati hiba történt</translation>
    </message>
    <message>
        <source>Payment acknowledged</source>
        <translation>Fizetés nyugtázva</translation>
    </message>
</context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>User Agent</translation>
    </message>
    <message>
        <source>Node/Service</source>
        <translation>Csomópont/Szolgáltatás</translation>
    </message>
    <message>
        <source>NodeId</source>
        <translation>Csomópont azonosító</translation>
    </message>
    <message>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Elküldve</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Fogadva</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message>
        <source>Enter a Litecoin address (e.g. %1)</source>
        <translation>Adjon meg egy Litecoin-címet (pl. %1)</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation>%1 n</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 ó</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 p</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation>%1 mp</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation>%1 ms</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n másodperc</numerusform><numerusform>%n másodperc</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n perc</numerusform><numerusform>%n perc</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n óra</numerusform><numerusform>%n óra</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n nap</numerusform><numerusform>%n nap</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n hét</numerusform><numerusform>%n hét</numerusform></translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 és %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n év</numerusform><numerusform>%n év</numerusform></translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 B</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely...</source>
        <translation>%1 még nem lépett ki biztonságosan...</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ismeretlen</translation>
    </message>
</context>
<context>
    <name>QObject::QObject</name>
    <message>
        <source>Error: Specified data directory "%1" does not exist.</source>
        <translation>Hiba: A megadott "%1" adatkönyvtár nem létezik.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hiba: %1</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>Kép &amp;mentése</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Kép má&amp;solása</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>QR-kód mentése</translation>
    </message>
    <message>
        <source>PNG Image (*.png)</source>
        <translation>PNG kép (*.png)</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Kliens verzió</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Információ</translation>
    </message>
    <message>
        <source>Debug window</source>
        <translation>Hibakereső ablak</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>Using BerkeleyDB version</source>
        <translation>BerkeleyDB verzió</translation>
    </message>
    <message>
        <source>Datadir</source>
        <translation>Adat elérési útja</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Indítás időpontja</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Kapcsolatok száma</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokklánc</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Blokkok aktuális száma</translation>
    </message>
    <message>
        <source>Memory Pool</source>
        <translation>Memória Halom</translation>
    </message>
    <message>
        <source>Current number of transactions</source>
        <translation>Tranzakciók pillanatnyi száma</translation>
    </message>
    <message>
        <source>Memory usage</source>
        <translation>Memóriahasználat</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation>&amp;Alaphelyzet</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Fogadva</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Elküldve</translation>
    </message>
    <message>
        <source>&amp;Peers</source>
        <translation>&amp;Peer-ek</translation>
    </message>
    <message>
        <source>Banned peers</source>
        <translation>Letiltott peer-ek</translation>
    </message>
    <message>
        <source>Select a peer to view detailed information.</source>
        <translation>Peer kijelölése a részletes információkért</translation>
    </message>
    <message>
        <source>Whitelisted</source>
        <translation>Engedélyezett</translation>
    </message>
    <message>
        <source>Direction</source>
        <translation>Irány</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>Starting Block</source>
        <translation>Kezdeti blokk</translation>
    </message>
    <message>
        <source>Synced Headers</source>
        <translation>Szikronizált fejlécek</translation>
    </message>
    <message>
        <source>Synced Blocks</source>
        <translation>Szinkronizált blokkok</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>User Agent</translation>
    </message>
    <message>
        <source>Open the %1 debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>A %1 hibakeresési naplófájl megnyitása a jelenlegi könyvtárból. Ez néhány másodpercig eltarthat nagyobb naplófájlok esetén.</translation>
    </message>
    <message>
        <source>Decrease font size</source>
        <translation>Betűméret csökkentése</translation>
    </message>
    <message>
        <source>Increase font size</source>
        <translation>Betűméret növelése</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Szolgáltatások</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation>Csatlakozási idő</translation>
    </message>
    <message>
        <source>Last Send</source>
        <translation>Utolsó küldés</translation>
    </message>
    <message>
        <source>Last Receive</source>
        <translation>Utolsó fogadás</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation>Ping idő</translation>
    </message>
    <message>
        <source>The duration of a currently outstanding ping.</source>
        <translation>A jelenlegi kiváló ping időtartama.</translation>
    </message>
    <message>
        <source>Ping Wait</source>
        <translation>Várakozás ping-re</translation>
    </message>
    <message>
        <source>Min Ping</source>
        <translation>Minimum Ping</translation>
    </message>
    <message>
        <source>Time Offset</source>
        <translation>Idő Eltolódás</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Utolsó blokk ideje</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Megnyitás</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzol</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Hálózati forgalom</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Összesen</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Be:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Ki:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Hibakeresési napló fájl</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Konzol ürítése</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation>1 &amp;óra</translation>
    </message>
    <message>
        <source>1 &amp;day</source>
        <translation>1 &amp;nap</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation>1 &amp;hét</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation>1 &amp;év</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Szétkapcsol</translation>
    </message>
    <message>
        <source>Ban for</source>
        <translation>Tiltás oka</translation>
    </message>
    <message>
        <source>&amp;Unban</source>
        <translation>&amp;Tiltás feloldása</translation>
    </message>
    <message>
        <source>Welcome to the %1 RPC console.</source>
        <translation>Üdv az %1 RPC konzoljában.</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and %1 to clear screen.</source>
        <translation>Az előzmények közötti navigálásához használd a fel és le nyilakat, és %1-t a képernyő törléséhez.</translation>
    </message>
    <message>
        <source>Type %1 for an overview of available commands.</source>
        <translation>Írja be a %1 parancsot az elérhető utasítások áttekintéséhez.</translation>
    </message>
    <message>
        <source>WARNING: Scammers have been active, telling users to type commands here, stealing their wallet contents. Do not use this console without fully understanding the ramifications of a command.</source>
        <translation>FIGYELEM: Csalók megpróbálnak felhasználókat rávenni, hogy parancsokat írjanak be ide, és ellopják a tárca tartalmát. Ne használja ezt a konzolt anélkül, hogy teljesen megértené egy parancs kiadásának a következményeit.</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation>Hálózat aktivitása letiltva</translation>
    </message>
    <message>
        <source>(node id: %1)</source>
        <translation>(csomópont azonosító: %1)</translation>
    </message>
    <message>
        <source>via %1</source>
        <translation>%1-n keresztül</translation>
    </message>
    <message>
        <source>never</source>
        <translation>soha</translation>
    </message>
    <message>
        <source>Inbound</source>
        <translation>Bejövő</translation>
    </message>
    <message>
        <source>Outbound</source>
        <translation>Kimenő</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nem</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Összeg:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Címke:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Üzenet:</translation>
    </message>
    <message>
        <source>An optional message to attach to the payment request, which will be displayed when the request is opened. Note: The message will not be sent with the payment over the Litecoin network.</source>
        <translation>Opciónális üzenet csatolása a fizetési kérelemhez, ami a kérelem megnyitásakor megjelenik. Megjegyzés: Az üzenet nem lesz elküldve a fizetéssel a Litecoin hálózaton.</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address.</source>
        <translation>Opcionális címke hozzáadása az új fogadó címhez.</translation>
    </message>
    <message>
        <source>Use this form to request payments. All fields are &lt;b&gt;optional&lt;/b&gt;.</source>
        <translation>Használja ezt az űrlapot fizetések kérésére. Minden mező &lt;b&gt;opcionális&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>An optional amount to request. Leave this empty or zero to not request a specific amount.</source>
        <translation>Egy opcionálisan kérhető összeg. Hagyja üresen, vagy írjon be nullát, ha nem kívánja használni.</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Az űrlap összes mezőjének törlése</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation>A kért kifizetések előzménye</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Fizetési kérelem</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation>Mutassa meg a kiválasztott kérelmet (ugyanaz, mint a duplaklikk)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Megmutatás</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>A kijelölt elemek törlése a listáról</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eltávolítás</translation>
    </message>
    <message>
        <source>Copy URI</source>
        <translation>URI másolása</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Címke másolása</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation>Üzenet másolása</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Összeg másolása</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>QR Code</source>
        <translation>QR-kód</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>&amp;URI másolása</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Cím másolása</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>Kép &amp;mentése</translation>
    </message>
    <message>
        <source>Request payment to %1</source>
        <translation>Fizetési kérelem tőle: %1</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Fizetési információ</translation>
    </message>
    <message>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Üzenet</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Tárca</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>A keletkezett URI túl hosszú, próbálja meg csökkenteni a cimke / üzenet szövegének méretét.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Hiba lépett fel az URI QR kóddá alakításakor.</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Üzenet</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(nincs üzenet)</translation>
    </message>
    <message>
        <source>(no amount requested)</source>
        <translation>(nem kért összeget)</translation>
    </message>
    <message>
        <source>Requested</source>
        <translation>Kért</translation>
    </message>
</context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Érmék küldése</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Pénzküldés beállításai</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Bemenetek...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automatikusan kiválasztva</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fedezethiány!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Mennyiség:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bájtok:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Öszeg:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Díj:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Eljárási díj után:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Visszajáró:</translation>
    </message>
    <message>
        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
        <translation>Ha ezt a beállítást engedélyezi, de a visszajáró cím érvénytelen, a visszajáró egy újonnan generált címre lesz küldve.</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation>Egyedi visszajáró cím</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Tranzakciós díj:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Választás...</translation>
    </message>
    <message>
        <source>Warning: Fee estimation is currently not possible.</source>
        <translation>Figyelem: A hozzávetőleges díjszámítás jelenleg nem lehetséges.</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation>kilobájtonként</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Elrejtés</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Ajánlott:</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>Egyedi:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Küldés egyszerre több címzettnek</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Az űrlap összes mezőjének törlése</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Porszem:</translation>
    </message>
    <message>
        <source>Confirmation time target:</source>
        <translation>Megerősítési idő cél:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Mindent töröl</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Egyenleg:</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Küldés</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Mennyiség másolása</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Összeg másolása</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Díj másolása</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Eljárási díj utáni másolás</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Bájtok másolása</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Por másolása</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Változás másolása</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>Biztosan elküldi?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>vagy</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Tranzakciós díj</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Az összegnek nagyobbnak kell lennie, mint 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Az összeg túlhaladja az egyenleged.</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>Tranzakció készítése sikertelen!</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Fizetési kérelem lejárt</translation>
    </message>
    <message>
        <source>Warning: Invalid Litecoin address</source>
        <translation>Figyelem: érvénytelen Litecoin cím</translation>
    </message>
    <message>
        <source>Confirm custom change address</source>
        <translation>Egyedi visszajáró cím megerősítése</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Összeg:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Címke:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Válasszon a korábban használt címek közül</translation>
    </message>
    <message>
        <source>This is a normal payment.</source>
        <translation>Ez egy normális fizetés.</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Cím beillesztése vágólapról</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>Bejegyzés eltávolítása</translation>
    </message>
    <message>
        <source>Use available balance</source>
        <translation>Elérhető egyenleg használata</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Üzenet:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Jegyzet:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    <message>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>%1 is shutting down...</source>
        <translation>%1 leáll...</translation>
    </message>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Ne kapcsold ki a számítógépet, amíg ez az üzenet el nem tűnik.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Aláírások - Aláír / Megerősít egy Üzenetet</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Válasszon a korábban használt címek közül</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Cím beillesztése vágólapról</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Aláírás</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>A pillanatnyi aláírás másolása a rendszer vágólapjára</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Mindent töröl</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Üzenet megerősítése</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>A beírt cím érvénytelen.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Ellenőrizze a címet majd próbálja újból.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>A tárca feloldása elutasítva</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Üzenet aláírása sikertelen</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Üzenet aláírva</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Ellenőrizze az aláírást majd próbálja újból</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Üzenet megerősítve.</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>KB/s</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Létrehozott</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Innen:</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ismeretlen</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Ide:</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>saját címek</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>megfigyelés</translation>
    </message>
    <message>
        <source>label</source>
        <translation>címke</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nem elfogadott</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Tranzakciós díj</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Nettó összeg</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Üzenet</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>Tranzakció azonosító</translation>
    </message>
    <message>
        <source>Transaction total size</source>
        <translation>Tranzakció teljes mérete</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>Kereskedő</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>Hibakeresési információk</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Tranzakció</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message>
        <source>true</source>
        <translation>igaz</translation>
    </message>
    <message>
        <source>false</source>
        <translation>hamis</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Nem megerősített</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generált de nem elfogadott</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Küldés neki</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Bányászott</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>megfigyelés</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tranzakció típusa.</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>E héten</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>E hónapban</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Előző hónapban</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Ez évben</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Tartomány...</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Küldés neki</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Bányászott</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimum összeg</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Cím másolása</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Címke másolása</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Összeg másolása</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Tranzakció ID másolása</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Címke szerkesztése</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Tranzakció részletei</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Vesszővel elválasztott adatok (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Jóváhagyva</translation>
    </message>
    <message>
        <source>Watch-only</source>
        <translation>Csak megtekintés</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Sikertelen export</translation>
    </message>
    <message>
        <source>Exporting Successful</source>
        <translation>Sikeres exportálás</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Érmék küldése</translation>
    </message>
    <message>
        <source>Increase:</source>
        <translation>Növelés:</translation>
    </message>
    <message>
        <source>New fee:</source>
        <translation>Új díj:</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Export</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>A jelenlegi fülön található adat exportálása fájlba</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Tárca biztonsági mentése</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Tárca adat (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Biztonsági mentés sikertelen</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation>Biztonsági mentés sikeres</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Litecoin Core</source>
        <translation>Litecoin Mag</translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>Szeretnéd újra építeni a blokk adatbázist most?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Hiba a blokk adatbázis inicializálásakor</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Hiba a blokk adatbázis betöltésekor</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>Hiba a blokk adatbázis megnyitásakor</translation>
    </message>
    <message>
        <source>Error: Disk space is low!</source>
        <translation>Hiba: Kicsi a lemezterület!</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importálás...</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Blokkok megerősítése...</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Tranzakció aláírása sikertelen</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>Ez egy fejlesztés alatt álló szoftver.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>A tranzakció összege túl kicsi</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>A tranzakció túl nagy</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation>Tárca/Tárcák megerősítése</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>%s is set very high!</source>
        <translation>%s túl magasra van állítva!</translation>
    </message>
    <message>
        <source>Starting network threads...</source>
        <translation>Hálózati szálak indítása...</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>A tranzakciók összege nem lehet negatív</translation>
    </message>
    <message>
        <source>Transaction must have at least one recipient</source>
        <translation>Legalább egy címzettnek kell lennie a tranzakcióban </translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fedezethiány</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>A blokkindex betöltése ...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Tárca betöltése...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Nem lehet lemásolni a pénztárcát</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Újraszkennelés</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Betöltés kész</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
</TS>